@@ -66,7 +66,7 @@ def do_sync_full_table(conn_config, stream, state, desired_columns, md_map):
             return state
         except Exception as e:
             LOGGER.warn("error on read for a stream: %s. Message: %s", stream['tap_stream_id'], e)
-            if attemp > 20:
+            if attemp > post_db.TRY_NUMBER:
                 raise e
             else:
                 attemp = attemp + 1
@@ -420,6 +420,8 @@ def main_impl():
         conn_config['sslmode'] = 'require'
 
     post_db.CURSOR_ITER_SIZE = int(args.config.get('itersize', post_db.CURSOR_ITER_SIZE))
+    post_db.TRY_NUMBER = int(args.config.get('trynumber', post_db.TRY_NUMBER))
+
 
     if args.discover:
         do_discovery(conn_config)
